@@ -1,4 +1,4 @@
-lm.select <- function(lms){
+lm.select <- function(lms, deltaAIC = FALSE){
       models <- matrix(ncol = 1, nrow = length(lms))
       res <- matrix(ncol = 5, nrow = length(lms))
       for(i in 1 : length(lms)){
@@ -13,10 +13,18 @@ lm.select <- function(lms){
       res[,5][i] <- press(lms[[i]])
           tm1 <- attributes(lms[[1]]$terms)$term.labels
           tmi <- attributes(lms[[i]]$terms)$term.labels
-          if(any(is.na(match(tmi,tm1)))){
+          if(deltaAIC == FALSE & any(is.na(match(tmi,tm1)))){
           message("Warning: subsequent models not a subset of first model, Cp values invlaid") }
 	models[i] <- as.matrix(format(lms[[i]]$call$formula))
       }
-res <- data.frame(Model = models, AIC = res[,1], AICc = res[,2], BIC = res[,3], Cp = res[,4], PRESS = res[,5])
-res
+res1 <- data.frame(Model = models, AIC = res[,1], AICc = res[,2], BIC = res[,3], Cp = res[,4], PRESS = res[,5])
+if(deltaAIC == TRUE){
+deltaAIC <- res[,1] - min(res[,1])
+rel.likelihood <- exp(-0.5*deltaAIC) 
+res1 <- data.frame(Model = models, deltaAIC = deltaAIC, Rel.likelihood = rel.likelihood, Akaike.weight = rel.likelihood/sum(rel.likelihood)) 
 }
+res1
+}
+
+
+
