@@ -1,6 +1,6 @@
 see.Fcdf.tck<-function () 
 {
-
+  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
     slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     nu1 <- 5
@@ -59,7 +59,9 @@ see.Fcdf.tck<-function ()
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
- }
+ 
+    on.exit(par(old.par))
+    }
 
 
 see.F.tck<-function () 
