@@ -54,7 +54,7 @@ see.exp.tck<-function ()
 }
 
 see.expcdf.tck<-function (){ 
-
+  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     theta <- 1
@@ -106,4 +106,6 @@ see.expcdf.tck<-function (){
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
+    
+    on.exit(par(old.par))
   }
\ No newline at end of file
