@@ -56,7 +56,7 @@ see.geo.tck<-function ()
  
 see.geocdf.tck<-function () 
 {
-
+  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
     slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
 
@@ -114,5 +114,6 @@ see.geocdf.tck<-function ()
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
+    on.exit(par(old.par))
 }
  
\ No newline at end of file
