@@ -65,7 +65,7 @@ see.lnorm.tck<-function ()
 
 
 see.lnormcdf.tck<-function (){ 
-
+  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
        slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     mu <- 0
@@ -129,5 +129,6 @@ see.lnormcdf.tck<-function (){
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
+    on.exit(par(old.par))
   }  
                             
\ No newline at end of file
