@@ -17,6 +17,9 @@ see.normcdf.tck <- function ()
     assign("ymin", tclVar(ymin), envir = slider.env)
     ymax <- round(dnorm(0, 0, 0.5), 2)
     assign("ymax", tclVar(ymax), envir = slider.env)
+    
+    old.par <- par(no.readonly = TRUE)
+    
     dev.new(height = 4, width = 8)
     par(mar = c(4.4, 4.5, 1, 0.5), cex = 0.85, oma = c(0, 0, 
         1.5, 0))
@@ -49,6 +52,7 @@ see.normcdf.tck <- function ()
             side = 3, cex = 0.9)
         dev.flush()
     }
+    
     tclServiceMode(TRUE)
     m <- tktoplevel()
     tkwm.title(m, "N(\u03bc, \u03c3\u00B2)")
@@ -92,7 +96,9 @@ see.normcdf.tck <- function ()
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
-}
+
+    on.exit(par(old.par))
+    }
 
 
 see.norm.tck<-function () 
