@@ -1,6 +1,6 @@
 see.roc.tck <- function () 
 {
-
+  old.par <- par(no.readonly = TRUE)
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check
     mu1 <- 0.4
@@ -138,5 +138,7 @@ see.roc.tck <- function ()
         side = "left")
     tkpack(tkbutton(m, text = "Exit", command = function() tkdestroy(m)), 
         side = "right")
-}
+
+    on.exit(par(old.par))
+    }
                                                                      
\ No newline at end of file
